@@ -82,7 +82,7 @@ void FocusHackWidget::focusPrevious()
 class SubcategoryModel : public QStandardItemModel
 {
 public:
-    SubcategoryModel(QAbstractItemModel *parentModel, QObject *parent = 0)
+    explicit SubcategoryModel(QAbstractItemModel *parentModel, QObject *parent = nullptr)
         : QStandardItemModel(parent),
           m_parentModel(parentModel)
     {}
@@ -115,7 +115,7 @@ private:
 class MostUsedModel : public QSortFilterProxyModel
 {
 public:
-    MostUsedModel(QObject *parent = 0)
+    explicit MostUsedModel(QObject *parent = nullptr)
         : QSortFilterProxyModel (parent)
     {
         sort(0, Qt::DescendingOrder);
@@ -162,7 +162,7 @@ public:
         updateModel();
     }
 
-    QHash<int, QByteArray> roleNames() const
+    QHash<int, QByteArray> roleNames() const override
     {
         QHash<int, QByteArray> roleNames;
         roleNames.insert(Qt::DisplayRole, "display");
@@ -232,20 +232,20 @@ public:
         delete aboutIcon;
     }
 
-    ToolTipManager *toolTipManager;
-    QQuickWidget * quickWidget;
+    ToolTipManager *toolTipManager = nullptr;
+    QQuickWidget * quickWidget = nullptr;
     KPackage::Package package;
-    SubcategoryModel * subCategoryModel;
-    MostUsedModel * mostUsedModel;
-    FocusHackWidget * mainWidget;
-    QQuickWidget * placeHolderWidget;
-    QHBoxLayout * mainLayout;
+    SubcategoryModel * subCategoryModel = nullptr;
+    MostUsedModel * mostUsedModel = nullptr;
+    FocusHackWidget * mainWidget = nullptr;
+    QQuickWidget * placeHolderWidget = nullptr;
+    QHBoxLayout * mainLayout = nullptr;
     KDeclarative::KDeclarative kdeclarative;
-    MenuProxyModel * categorizedModel;
-    MenuProxyModel * searchModel;
-    KAboutData * aboutIcon;
-    ModuleView * moduleView;
-    KActionCollection *collection;
+    MenuProxyModel * categorizedModel = nullptr;
+    MenuProxyModel * searchModel = nullptr;
+    KAboutData * aboutIcon = nullptr;
+    ModuleView * moduleView = nullptr;
+    KActionCollection *collection = nullptr;
     QPersistentModelIndex activeCategoryIndex;
     int activeCategory;
     int activeSubCategory;
@@ -256,13 +256,13 @@ SidebarMode::SidebarMode( QObject *parent, const QVariantList& )
     , d( new Private() )
 {
     qApp->setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
-    d->aboutIcon = new KAboutData( "SidebarView", i18n( "Sidebar View" ),
-                                 "1.0", i18n( "Provides a categorized sidebar for control modules." ),
+    d->aboutIcon = new KAboutData( QStringLiteral("SidebarView"), i18n( "Sidebar View" ),
+                                 QStringLiteral("1.0"), i18n( "Provides a categorized sidebar for control modules." ),
                                  KAboutLicense::GPL, i18n( "(c) 2017, Marco Martin" ) );
-    d->aboutIcon->addAuthor( i18n( "Marco Martin" ), i18n( "Author" ), "mart@kde.org" );
-    d->aboutIcon->addAuthor( i18n( "Ben Cooksley" ), i18n( "Author" ), "bcooksley@kde.org" );
-    d->aboutIcon->addAuthor( i18n( "Mathias Soeken" ), i18n( "Developer" ), "msoeken@informatik.uni-bremen.de" );
-    d->aboutIcon->setProgramIconName( "view-sidetree" );
+    d->aboutIcon->addAuthor( i18n( "Marco Martin" ), i18n( "Author" ), QStringLiteral("mart@kde.org") );
+    d->aboutIcon->addAuthor( i18n( "Ben Cooksley" ), i18n( "Author" ), QStringLiteral("bcooksley@kde.org") );
+    d->aboutIcon->addAuthor( i18n( "Mathias Soeken" ), i18n( "Developer" ), QStringLiteral("msoeken@informatik.uni-bremen.de") );
+    d->aboutIcon->setProgramIconName( QStringLiteral("view-sidetree") );
 
     qmlRegisterType<QAction>();
 }
@@ -344,7 +344,7 @@ void SidebarMode::initEvent()
     d->mainLayout->setContentsMargins(0, 0, 0, 0);
     d->moduleView = new ModuleView( d->mainWidget );
     connect( d->moduleView, &ModuleView::moduleChanged, this, &SidebarMode::moduleLoaded );
-    d->quickWidget = 0;
+    d->quickWidget = nullptr;
     moduleView()->setFaceType(KPageView::Plain);
 }
 
@@ -378,7 +378,7 @@ void SidebarMode::hideToolTip()
     d->toolTipManager->hideToolTip();
 }
 
-Q_INVOKABLE void SidebarMode::loadMostUsed(int index)
+void SidebarMode::loadMostUsed(int index)
 {
     const QModelIndex idx = d->mostUsedModel->index(index, 0);
     d->moduleView->closeModules();
@@ -413,10 +413,12 @@ int SidebarMode::activeCategory() const
 void SidebarMode::setActiveCategory(int cat)
 {
     const QModelIndex idx = d->searchModel->index(cat, 0);
-    d->activeCategoryIndex = idx;
     const int newCategoryRow = d->searchModel->mapToSource(idx).row();
 
-    if (d->activeCategory ==newCategoryRow) {
+    if (d->activeCategory == newCategoryRow) {
+        return;
+    }
+    if( !d->moduleView->resolveChanges() ) {
         return;
     }
 
@@ -440,6 +442,10 @@ void SidebarMode::setActiveSubCategory(int cat)
         return;
     }
 
+    if( !d->moduleView->resolveChanges() ) {
+        return;
+    }
+
     d->activeSubCategory = cat;
     d->moduleView->closeModules();
     d->moduleView->loadModule( d->subCategoryModel->index(cat, 0) );
@@ -466,8 +472,8 @@ void SidebarMode::initWidget()
     d->quickWidget->quickWindow()->setTitle(i18n("Sidebar"));
     d->quickWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
 
-    d->quickWidget->engine()->rootContext()->setContextProperty("systemsettings", this);
-    d->package = KPackage::PackageLoader::self()->loadPackage("KPackage/GenericQML");
+    d->quickWidget->engine()->rootContext()->setContextProperty(QStringLiteral("systemsettings"), this);
+    d->package = KPackage::PackageLoader::self()->loadPackage(QStringLiteral("KPackage/GenericQML"));
     d->package.setPath(QStringLiteral("org.kde.systemsettings.sidebar"));
 
     d->kdeclarative.setDeclarativeEngine(d->quickWidget->engine());
@@ -501,8 +507,8 @@ void SidebarMode::initWidget()
     d->placeHolderWidget->quickWindow()->setTitle(i18n("Most Used"));
     d->placeHolderWidget->setResizeMode(QQuickWidget::SizeRootObjectToView);
     d->placeHolderWidget->engine()->rootContext()->setContextObject(new KLocalizedContext(d->placeHolderWidget));
-    d->placeHolderWidget->engine()->rootContext()->setContextProperty("systemsettings", this);
-    d->placeHolderWidget->setSource(QUrl::fromLocalFile(d->package.filePath("ui", "introPage.qml")));
+    d->placeHolderWidget->engine()->rootContext()->setContextProperty(QStringLiteral("systemsettings"), this);
+    d->placeHolderWidget->setSource(QUrl::fromLocalFile(d->package.filePath("ui", QStringLiteral("introPage.qml"))));
     connect(d->placeHolderWidget->rootObject(), SIGNAL(focusNextRequest()), d->mainWidget, SLOT(focusNext()));
     connect(d->placeHolderWidget->rootObject(), SIGNAL(focusPreviousRequest()), d->mainWidget, SLOT(focusPrevious()));
     d->placeHolderWidget->installEventFilter(this);
@@ -513,7 +519,7 @@ void SidebarMode::initWidget()
     d->mainLayout->addWidget( d->placeHolderWidget );
     emit changeToolBarItems(BaseMode::NoItems);
 
-    d->mostUsedModel->setResultModel(new ResultModel( AllResources | Agent("org.kde.systemsettings") | HighScoredFirst | Limit(5), this));
+    d->mostUsedModel->setResultModel(new ResultModel( AllResources | Agent(QStringLiteral("org.kde.systemsettings")) | HighScoredFirst | Limit(5), this));
 }
 
 bool SidebarMode::eventFilter(QObject* watched, QEvent* event)
